@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.014;
 
-our $VERSION = '1.98';
+our $VERSION = '2.00';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -448,13 +448,13 @@ sub get_station_p {
 			);
 			return;
 		}
-	)->catch(
+	  )->catch(
 		sub {
 			my ($err) = @_;
 			$promise->reject($err);
 			return;
 		}
-	)->wait;
+	  )->wait;
 
 	return $promise;
 }
@@ -672,13 +672,13 @@ sub get_timetable_p {
 			$promise->resolve;
 			return;
 		}
-	)->catch(
+	  )->catch(
 		sub {
 			my ($err) = @_;
 			$promise->reject($err);
 			return;
 		}
-	)->wait;
+	  )->wait;
 	return $promise;
 }
 
@@ -736,13 +736,13 @@ sub get_realtime_p {
 			$promise->resolve;
 			return;
 		}
-	)->catch(
+	  )->catch(
 		sub {
 			my ($err) = @_;
 			$promise->reject("Failed to fetch realtime data: $err");
 			return;
 		}
-	)->wait;
+	  )->wait;
 	return $promise;
 }
 
@@ -996,18 +996,16 @@ Non-blocking variant (EXPERIMENTAL):
 
 =head1 VERSION
 
-version 1.98
+version 2.00
 
 =head1 DEPRECATION NOTICE
 
 As of May 2024, the backend service that this module relies on is deprecated
-and may cease operation in the near future. There is no immediate successor.
-Hence, Travel::Status::DE::IRIS is no longer actively maintained.  There is no
-promise that issues and merge requests will be reviewed or merged.
+and may cease operation in the near future. There is no successor with feature
+parity.  Travel::Status::DE::IRIS is no longer actively maintained.  There is
+no promise that issues and merge requests will be reviewed or merged.
 
-The Travel::Status::DE::HAFAS(3pm) module provides similar features. However,
-its default "DB" backend is also deprecated. There is no migration path to a
-Deutsche Bahn departure monitor that is not deprecated at the moment.
+The Travel::Status::DE::DBRIS(3pm) module provides similar features.
 
 =head1 DESCRIPTION
 
@@ -1210,7 +1208,7 @@ L<https://github.com/derf/Travel-Status-DE-IRIS>
 
 =head1 AUTHOR
 
-Copyright (C) 2013-2024 by Birte Kristina Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2013-2025 by Birte Kristina Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
